==> foundation-theme-1.0.1.tgz: package/src/common/utils/color-utils.ts <==
import applySpec from 'ramda/src/applySpec';
import compose from 'ramda/src/compose';
import pathOr from 'ramda/src/pathOr';
import propEq from 'ramda/src/propEq';
import ifElse from 'ramda/src/ifElse';

import { FoundationTheme as FT } from '..';

type PaletteColor = null | {
    main?: string;
    contrastText?: string;
    darkMode?: { main: string; contrastText: string };
};

const getThemeProps = applySpec<{
    theme: FT.Theme;
    darkModeEnabled?: boolean;
}>({
    theme: pathOr({}, ['theme']),
    darkModeEnabled: pathOr(true, ['darkModeEnabled']),
});

const getTheme = pathOr({}, ['theme']);

/**
 * Returns the color hex value from the theme's color object.
 *
 * @example
 * theme = {
 *    colors: {
 *        [colorType]: {
 *            [variant]: HexValue
 *        }
 *    }
 * }
 *
 * @param colorName - The color type has to be passed
 * Examples: primary | neutral | accentColorA | accentColorB | accentColorC |
 * accentColorD | success | warning | red | info | custom
 * @param variant - Each color type has different variant
 * Examples: 10 | 20 | 30 | 40 | 100 | 200 | 300
 * @returns The hex value if color and variant are found.
 *
 */
const color = (colorType: keyof FT.Colors, variant: string | number) =>
    compose(pathOr('', ['colors', colorType, variant]), getTheme);

type ColorInput = {
    colorType: keyof FT.Colors;
    variant: string | number;
};

export const themeColor = (light: ColorInput, dark: ColorInput) => {
    return ifElse(
        isDarkMode,
        compose(pathOr('', ['colors', dark.colorType, dark.variant]), getTheme),
        compose(pathOr('', ['colors', light.colorType, light.variant]), getTheme)
    );
};
/**
 * isDarkMode verifies if the current theme has dark theme enabled.
 * {
 *    theme: {
 *        mode === "dark"
 *    }
 * }
 *
 * @returns true if current theme's mode is dark.
 *
 */

const isDarkMode = compose(propEq('dark', 'mode'), pathOr({ mode: null }, ['palette']), getTheme);

const getPalette = (color: FT.PaletteColors = 'primary') =>
    compose(function (appTheme) {
        const { theme, darkModeEnabled } = appTheme;
        const currentPalette: PaletteColor = pathOr({}, ['palette', color])(theme);
        const darkMode = currentPalette?.darkMode;
        if (isDarkMode(appTheme) && darkModeEnabled && darkMode?.main) {
            return {
                ...currentPalette,
                ...darkMode,
            };
        }
        return currentPalette;
    }, getThemeProps);

/**
 * Returns the color hex value from the theme's color object.
 *
 * Note: This will not switch between dark and light mode if the darkModeEnabled is passed as false,
 * from the component.
 * Also if there is no darkMode property available in theme's palette for the particular color it will not switch mode.
 *
 * @example
 * theme = {
 *    palette: {
 *        [paletteColorType]: {
 *            main: HexColorString,
 *            contrastText: HexColorString,
 *            darkMode: {
 *                main: HexColorString,
 *                contrastText: HexColorString,
 *            },
 *            buttonState: {
 *                hovered: HexColorString,
 *                pressed: HexColorString,
 *                focused: HexColorString,
 *                disabled: HexColorString,
 *                disabledText: HexColorString
 *            }
 *        }
 *    }
 * }
 *
 * @param paletteColorType - The palette color that has to be passed
 * Examples: primary | neutral | accentColorA | accentColorB | accentColorC |
 * accentColorD | success | warning | red | info
 * @param variant - Each color type has different variant
 * Examples: main | contrastText
 * @returns The hex value if color and variant are found.
 *
 */

const paletteColor = (paletteColorType: FT.PaletteColors = 'primary', variant?: 'main' | 'contrastText') =>
    compose(pathOr('', [variant || 'main']), getPalette(paletteColorType));

/**
 * Returns the button color hex value according to the state .
 *
 * Note: This will not switch between dark and light mode if the darkModeEnabled is passed as false,
 * from the component.
 *
 * @example
 * theme = {
 *    palette: {
 *        [paletteColorType]: {
 *            main: HexColorString,
 *            contrastText: HexColorString,
 *            darkMode: {
 *                main: HexColorString,
 *                contrastText: HexColorString,
 *            },
 *            buttonState: {
 *                hovered: HexColorString,
 *                pressed: HexColorString,
 *                focused: HexColorString,
 *                disabled: HexColorString,
 *                disabledText: HexColorString
 *            }
 *        }
 *    }
 * }
 *
 * @param paletteColorType - The palette color that has to be passed
 * Examples: primary | neutral | accentColorA | accentColorB | accentColorC |
 * accentColorD | success | warning | red | info
 * @param state - Each color type has different variant
 * Examples: hovered | pressed | focused | disabled | disabledText
 * @returns The hex value if color and variant are found.
 *
 */

const getButtonState = (state: string) => pathOr('', ['buttonState', state]);

const buttonColor = (paletteColorType: FT.PaletteColors = 'primary', state: keyof FT.ButtonState) =>
    compose(getButtonState(state), getPalette(paletteColorType));

export const ColorUtils = {
    color,
    paletteColor,
    buttonColor,
    isDarkMode,
    themeColor,
};

==> foundation-theme-1.2.0.tgz: package/src/common/utils/color-utils.ts <==
import applySpec from 'ramda/src/applySpec';
import compose from 'ramda/src/compose';
import ifElse from 'ramda/src/ifElse';
import pathOr from 'ramda/src/pathOr';
import propEq from 'ramda/src/propEq';

import { FoundationTheme as FT } from '..';
import { getGenomeColor } from '../themes/genome-colors/ColorFunctions';

type PaletteColor = null | {
    main?: string;
    contrastText?: string;
    darkMode?: { main: string; contrastText: string };
};

const getThemeProps = applySpec<{
    theme: FT.Theme;
    darkModeEnabled?: boolean;
}>({
    theme: pathOr({}, ['theme']),
    darkModeEnabled: pathOr(true, ['darkModeEnabled']),
});

const getTheme = pathOr({}, ['theme']);

/**
 * Returns the color hex value from the theme's color object.
 *
 * @example
 * theme = {
 *    colors: {
 *        [colorType]: {
 *            [variant]: HexValue
 *        }
 *    }
 * }
 *
 * @param colorName - The color type has to be passed
 * Examples: primary | neutral | accentColorA | accentColorB | accentColorC |
 * accentColorD | success | warning | red | info | custom
 * @param variant - Each color type has different variant
 * Examples: 10 | 20 | 30 | 40 | 100 | 200 | 300
 * @returns The hex value if color and variant are found.
 *
 */
const color = (colorType: keyof FT.Colors, variant: string | number) =>
    compose(pathOr('', ['colors', colorType, variant]), getTheme);

type ColorInput = {
    colorType: keyof FT.Colors;
    variant: string | number;
};

export const themeColor = (light: ColorInput, dark: ColorInput) => {
    return ifElse(
        isDarkMode,
        compose(pathOr('', ['colors', dark.colorType, dark.variant]), getTheme),
        compose(pathOr('', ['colors', light.colorType, light.variant]), getTheme)
    );
};
/**
 * isDarkMode verifies if the current theme has dark theme enabled.
 * {
 *    theme: {
 *        mode === "dark"
 *    }
 * }
 *
 * @returns true if current theme's mode is dark.
 *
 */

const isDarkMode = compose(propEq<string | null, string>('dark', 'mode'), pathOr({ mode: '' }, ['palette']), getTheme);
const getPalette = (color: FT.PaletteColors = 'primary') =>
    compose(function (appTheme) {
        const { theme, darkModeEnabled } = appTheme;
        const currentPalette: PaletteColor = pathOr({}, ['palette', color])(theme);
        const darkMode = currentPalette?.darkMode;
        if (isDarkMode(appTheme) && darkModeEnabled && darkMode?.main) {
            return {
                ...currentPalette,
                ...darkMode,
            };
        }
        return currentPalette;
    }, getThemeProps);

/**
 * Returns the color hex value from the theme's color object.
 *
 * Note: This will not switch between dark and light mode if the darkModeEnabled is passed as false,
 * from the component.
 * Also if there is no darkMode property available in theme's palette for the particular color it will not switch mode.
 *
 * @example
 * theme = {
 *    palette: {
 *        [paletteColorType]: {
 *            main: HexColorString,
 *            contrastText: HexColorString,
 *            darkMode: {
 *                main: HexColorString,
 *                contrastText: HexColorString,
 *            },
 *            buttonState: {
 *                hovered: HexColorString,
 *                pressed: HexColorString,
 *                focused: HexColorString,
 *                disabled: HexColorString,
 *                disabledText: HexColorString
 *            }
 *        }
 *    }
 * }
 *
 * @param paletteColorType - The palette color that has to be passed
 * Examples: primary | neutral | accentColorA | accentColorB | accentColorC |
 * accentColorD | success | warning | red | info
 * @param variant - Each color type has different variant
 * Examples: main | contrastText
 * @returns The hex value if color and variant are found.
 *
 */

const paletteColor = (paletteColorType: FT.PaletteColors = 'primary', variant?: 'main' | 'contrastText') =>
    compose(pathOr('', [variant || 'main']), getPalette(paletteColorType));

/**
 * Returns the button color hex value according to the state .
 *
 * Note: This will not switch between dark and light mode if the darkModeEnabled is passed as false,
 * from the component.
 *
 * @example
 * theme = {
 *    palette: {
 *        [paletteColorType]: {
 *            main: HexColorString,
 *            contrastText: HexColorString,
 *            darkMode: {
 *                main: HexColorString,
 *                contrastText: HexColorString,
 *            },
 *            buttonState: {
 *                hovered: HexColorString,
 *                pressed: HexColorString,
 *                focused: HexColorString,
 *                disabled: HexColorString,
 *                disabledText: HexColorString
 *            }
 *        }
 *    }
 * }
 *
 * @param paletteColorType - The palette color that has to be passed
 * Examples: primary | neutral | accentColorA | accentColorB | accentColorC |
 * accentColorD | success | warning | red | info
 * @param state - Each color type has different variant
 * Examples: hovered | pressed | focused | disabled | disabledText
 * @returns The hex value if color and variant are found.
 *
 */

const getButtonState = (state: string) => pathOr('', ['buttonState', state]);

const buttonColor = (paletteColorType: FT.PaletteColors = 'primary', state: keyof FT.ButtonState) =>
    compose(getButtonState(state), getPalette(paletteColorType));

export const ColorUtils = {
    color,
    paletteColor,
    buttonColor,
    isDarkMode,
    themeColor,
    getGenomeColor,
};
